@@ -11,7 +11,7 @@ Utilities to read resource file containing compilation of CCDC models correspond
 for PDB chemical components.
 
 """
-__docformat__ = "google.en"
+__docformat__ = "google en"
 __author__ = "John Westbrook"
 __email__ = "jwest@rcsb.rutgers.edu"
 __license__ = "Apache 2.0"
