@@ -6,7 +6,7 @@
 # Pharos relational database (TCRDv6.7).
 ##
 
-__docformat__ = "google.en"
+__docformat__ = "google en"
 __author__ = "John Westbrook"
 __email__ = "jwest@rcsb.rutgers.edu"
 __license__ = "Apache 2.0"
