@@ -10,7 +10,7 @@
 Utilities to read the RESID resource file and build loadable documents and identifier
     correspondences.
 """
-__docformat__ = "google.en"
+__docformat__ = "google en"
 __author__ = "John Westbrook"
 __email__ = "jwest@rcsb.rutgers.edu"
 __license__ = "Apache 2.0"
