@@ -1,5 +1,5 @@
-__docformat__ = "google.en"
+__docformat__ = "google en"
 __author__ = "John Westbrook"
 __email__ = "john.westbrook@rcsb.org"
 __license__ = "Apache 2.0"
-__version__ = "0.72"
+__version__ = "0.73"
